<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('client_contact');

// 记录访问日志
record_log('访问联系人管理页面');

// 添加/编辑联系人处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加联系人
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $position = isset($_POST['position']) ? trim($_POST['position']) : '';
        $mobile = isset($_POST['mobile']) ? trim($_POST['mobile']) : '';
        $email = isset($_POST['email']) ? trim($_POST['email']) : '';
        $birthday = isset($_POST['birthday']) ? trim($_POST['birthday']) : null;
        $is_primary = isset($_POST['is_primary']) ? intval($_POST['is_primary']) : 0;

        if ($client_id <= 0 || empty($name)) {
            $error = '请填写完整联系人信息！';
        } else {
            try {
                // 如果设置为主要联系人，需要将该客户的其他联系人设为非主要
                if ($is_primary == 1) {
                    $stmt = $pdo->prepare("UPDATE crm_contacts SET is_primary = 0 WHERE client_id = ?");
                    $stmt->execute([$client_id]);
                }

                // 添加联系人
                $stmt = $pdo->prepare("INSERT INTO crm_contacts (client_id, name, position, mobile, email, birthday, is_primary) VALUES (?, ?, ?, ?, ?, ?, ?)");
                $result = $stmt->execute([$client_id, $name, $position, $mobile, $email, $birthday, $is_primary]);

                if ($result) {
                    record_log("添加联系人：{$name}");
                    $success = '联系人添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: contact.php?success=add');
                    exit;
                } else {
                    $error = '联系人添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑联系人
    elseif ($_POST['action'] == 'edit') {
        $contact_id = isset($_POST['contact_id']) ? intval($_POST['contact_id']) : 0;
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $position = isset($_POST['position']) ? trim($_POST['position']) : '';
        $mobile = isset($_POST['mobile']) ? trim($_POST['mobile']) : '';
        $email = isset($_POST['email']) ? trim($_POST['email']) : '';
        $birthday = isset($_POST['birthday']) ? trim($_POST['birthday']) : null;
        $is_primary = isset($_POST['is_primary']) ? intval($_POST['is_primary']) : 0;

        if ($contact_id <= 0 || $client_id <= 0 || empty($name)) {
            $error = '请填写完整联系人信息！';
        } else {
            try {
                // 如果设置为主要联系人，需要将该客户的其他联系人设为非主要
                if ($is_primary == 1) {
                    $stmt = $pdo->prepare("UPDATE crm_contacts SET is_primary = 0 WHERE client_id = ? AND id != ?");
                    $stmt->execute([$client_id, $contact_id]);
                }

                // 更新联系人信息
                $stmt = $pdo->prepare("UPDATE crm_contacts SET client_id = ?, name = ?, position = ?, mobile = ?, email = ?, birthday = ?, is_primary = ? WHERE id = ?");
                $result = $stmt->execute([$client_id, $name, $position, $mobile, $email, $birthday, $is_primary, $contact_id]);

                if ($result) {
                    record_log("编辑联系人：{$name}");
                    $success = '联系人信息更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: contact.php?success=edit');
                    exit;
                } else {
                    $error = '联系人信息更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除联系人
    elseif ($_POST['action'] == 'delete') {
        $contact_id = isset($_POST['contact_id']) ? intval($_POST['contact_id']) : 0;

        if ($contact_id <= 0) {
            $error = '无效的联系人ID！';
        } else {
            try {
                // 获取联系人名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name FROM crm_contacts WHERE id = ?");
                $stmt->execute([$contact_id]);
                $contact = $stmt->fetch();

                if (!$contact) {
                    $error = '联系人不存在！';
                } else {
                    // 删除联系人
                    $stmt = $pdo->prepare("DELETE FROM crm_contacts WHERE id = ?");
                    $result = $stmt->execute([$contact_id]);

                    if ($result) {
                        record_log("删除联系人：{$contact['name']}");
                        $success = '联系人删除成功！';
                    } else {
                        $error = '联系人删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有客户（用于选择关联客户）
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 获取所有联系人
try {
    $stmt = $pdo->query("
        SELECT c.*, cl.client_name
        FROM crm_contacts c 
        LEFT JOIN crm_clients cl ON c.client_id = cl.id
        ORDER BY c.id DESC
    ");
    $contacts = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取联系人列表失败：' . $e->getMessage();
    $contacts = [];
}

// 判断是否显示表单
$show_form = false;
$edit_contact = null;

// 编辑联系人时显示表单并获取联系人信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM crm_contacts WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_contact = $stmt->fetch();
        if (!$edit_contact) {
            $error = '联系人不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取联系人信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加联系人时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '联系人添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '联系人信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>联系人管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客户管理</a> &gt; 联系人管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="contact.php?action=add" class="btn btn-add">添加联系人</a>
            </div>

            <!-- 添加/编辑联系人表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_contact ? '编辑联系人' : '添加联系人'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_contact ? 'edit' : 'add'; ?>">
                        <?php if ($edit_contact): ?>
                            <input type="hidden" name="contact_id" value="<?php echo $edit_contact['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="client_id">所属客户：</label>
                            <select id="client_id" name="client_id" required>
                                <option value="">请选择客户</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>" <?php echo ($edit_contact && $edit_contact['client_id'] == $client['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($client['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="name">姓名：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_contact ? htmlspecialchars($edit_contact['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="position">职位：</label>
                            <input type="text" id="position" name="position" value="<?php echo $edit_contact ? htmlspecialchars($edit_contact['position']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="mobile">手机：</label>
                            <input type="text" id="mobile" name="mobile" value="<?php echo $edit_contact ? htmlspecialchars($edit_contact['mobile']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="email">邮箱：</label>
                            <input type="email" id="email" name="email" value="<?php echo $edit_contact ? htmlspecialchars($edit_contact['email']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="birthday">生日：</label>
                            <input type="date" id="birthday" name="birthday" value="<?php echo $edit_contact && $edit_contact['birthday'] ? date('Y-m-d', strtotime($edit_contact['birthday'])) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="is_primary">主要联系人：</label>
                            <select id="is_primary" name="is_primary">
                                <option value="0" <?php echo ($edit_contact && $edit_contact['is_primary'] == 0) ? 'selected' : ''; ?>>否</option>
                                <option value="1" <?php echo ($edit_contact && $edit_contact['is_primary'] == 1) ? 'selected' : ''; ?>>是</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="contact.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 联系人列表 -->
            <div class="table-container">
                <h3>联系人列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>姓名</th>
                            <th>所属客户</th>
                            <th>职位</th>
                            <th>手机</th>
                            <th>邮箱</th>
                            <th>生日</th>
                            <th>主要联系人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($contacts)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无联系人数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($contacts as $contact): ?>
                                <tr>
                                    <td><?php echo $contact['id']; ?></td>
                                    <td><?php echo htmlspecialchars($contact['name']); ?></td>
                                    <td><?php echo htmlspecialchars($contact['client_name']); ?></td>
                                    <td><?php echo htmlspecialchars($contact['position'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($contact['mobile'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($contact['email'] ?: '-'); ?></td>
                                    <td><?php echo $contact['birthday'] ? date('Y-m-d', strtotime($contact['birthday'])) : '-'; ?></td>
                                    <td><?php echo $contact['is_primary'] == 1 ? '<span class="status-active">是</span>' : '否'; ?></td>
                                    <td><?php echo $contact['create_time']; ?></td>
                                    <td>
                                        <a href="contact.php?action=edit&id=<?php echo $contact['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="contact_id" value="<?php echo $contact['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除联系人 \'<?php echo htmlspecialchars($contact['name']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>