<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('client_profile');

// 记录访问日志
record_log('访问客户档案页面');

// 添加/编辑客户处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加客户
    if ($_POST['action'] == 'add') {
        $client_name = isset($_POST['client_name']) ? trim($_POST['client_name']) : '';
        $client_type = isset($_POST['client_type']) ? intval($_POST['client_type']) : 1;
        $client_level = isset($_POST['client_level']) ? intval($_POST['client_level']) : 2;
        $industry = isset($_POST['industry']) ? trim($_POST['industry']) : '';
        $address = isset($_POST['address']) ? trim($_POST['address']) : '';
        $owner_user_id = isset($_POST['owner_user_id']) ? intval($_POST['owner_user_id']) : $_SESSION['user_id'];

        if (empty($client_name)) {
            $error = '请填写客户名称！';
        } else {
            try {
                // 检查客户名称是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM crm_clients WHERE client_name = ?");
                $stmt->execute([$client_name]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '客户名称已存在！';
                } else {
                    // 添加客户
                    $stmt = $pdo->prepare("INSERT INTO crm_clients (client_name, client_type, client_level, industry, address, owner_user_id) VALUES (?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$client_name, $client_type, $client_level, $industry, $address, $owner_user_id]);

                    if ($result) {
                        record_log("添加客户：{$client_name}");
                        $success = '客户添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: profile.php?success=add');
                        exit;
                    } else {
                        $error = '客户添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑客户
    elseif ($_POST['action'] == 'edit') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $client_name = isset($_POST['client_name']) ? trim($_POST['client_name']) : '';
        $client_type = isset($_POST['client_type']) ? intval($_POST['client_type']) : 1;
        $client_level = isset($_POST['client_level']) ? intval($_POST['client_level']) : 2;
        $industry = isset($_POST['industry']) ? trim($_POST['industry']) : '';
        $address = isset($_POST['address']) ? trim($_POST['address']) : '';
        $owner_user_id = isset($_POST['owner_user_id']) ? intval($_POST['owner_user_id']) : $_SESSION['user_id'];

        if ($client_id <= 0 || empty($client_name)) {
            $error = '请填写完整客户信息！';
        } else {
            try {
                // 检查客户名称是否已被其他客户使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM crm_clients WHERE client_name = ? AND id != ?");
                $stmt->execute([$client_name, $client_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '客户名称已被其他客户使用！';
                } else {
                    // 更新客户信息
                    $stmt = $pdo->prepare("UPDATE crm_clients SET client_name = ?, client_type = ?, client_level = ?, industry = ?, address = ?, owner_user_id = ? WHERE id = ?");
                    $result = $stmt->execute([$client_name, $client_type, $client_level, $industry, $address, $owner_user_id, $client_id]);

                    if ($result) {
                        record_log("编辑客户：{$client_name}");
                        $success = '客户信息更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: profile.php?success=edit');
                        exit;
                    } else {
                        $error = '客户信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除客户
    elseif ($_POST['action'] == 'delete') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;

        if ($client_id <= 0) {
            $error = '无效的客户ID！';
        } else {
            try {
                // 获取客户名称，用于日志记录
                $stmt = $pdo->prepare("SELECT client_name FROM crm_clients WHERE id = ?");
                $stmt->execute([$client_id]);
                $client = $stmt->fetch();

                if (!$client) {
                    $error = '客户不存在！';
                } else {
                    // 删除客户
                    $stmt = $pdo->prepare("DELETE FROM crm_clients WHERE id = ?");
                    $result = $stmt->execute([$client_id]);

                    if ($result) {
                        record_log("删除客户：{$client['client_name']}");
                        $success = '客户删除成功！';
                    } else {
                        $error = '客户删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有用户（用于选择负责人）
try {
    $stmt = $pdo->query("SELECT id, username FROM sys_users WHERE status = 1 ORDER BY id");
    $users = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取用户列表失败：' . $e->getMessage();
    $users = [];
}

// 获取所有客户
try {
    $stmt = $pdo->query("
        SELECT c.*, u.username as owner_name 
        FROM crm_clients c 
        LEFT JOIN sys_users u ON c.owner_user_id = u.id 
        ORDER BY c.id DESC
    ");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 判断是否显示表单
$show_form = false;
$edit_client = null;

// 编辑客户时显示表单并获取客户信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM crm_clients WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_client = $stmt->fetch();
        if (!$edit_client) {
            $error = '客户不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取客户信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加客户时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '客户添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '客户信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>客户档案</h2>
            <div class="breadcrumb">
                <a href="index.php">客户管理</a> &gt; 客户档案
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="profile.php?action=add" class="btn btn-add">添加客户</a>
            </div>

            <!-- 添加/编辑客户表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_client ? '编辑客户' : '添加客户'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_client ? 'edit' : 'add'; ?>">
                        <?php if ($edit_client): ?>
                            <input type="hidden" name="client_id" value="<?php echo $edit_client['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="client_name">客户名称：</label>
                            <input type="text" id="client_name" name="client_name" value="<?php echo $edit_client ? htmlspecialchars($edit_client['client_name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="client_type">客户类型：</label>
                            <select id="client_type" name="client_type">
                                <option value="1" <?php echo ($edit_client && $edit_client['client_type'] == 1) ? 'selected' : ''; ?>>企业</option>
                                <option value="2" <?php echo ($edit_client && $edit_client['client_type'] == 2) ? 'selected' : ''; ?>>个人</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="client_level">客户级别：</label>
                            <select id="client_level" name="client_level">
                                <option value="1" <?php echo ($edit_client && $edit_client['client_level'] == 1) ? 'selected' : ''; ?>>VIP客户</option>
                                <option value="2" <?php echo ($edit_client && $edit_client['client_level'] == 2) ? 'selected' : ''; ?>>普通客户</option>
                                <option value="3" <?php echo ($edit_client && $edit_client['client_level'] == 3) ? 'selected' : ''; ?>>潜在客户</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="industry">所属行业：</label>
                            <input type="text" id="industry" name="industry" value="<?php echo $edit_client ? htmlspecialchars($edit_client['industry']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="address">地址：</label>
                            <input type="text" id="address" name="address" value="<?php echo $edit_client ? htmlspecialchars($edit_client['address']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="owner_user_id">负责人：</label>
                            <select id="owner_user_id" name="owner_user_id">
                                <?php foreach ($users as $user): ?>
                                    <option value="<?php echo $user['id']; ?>" <?php echo ($edit_client && $edit_client['owner_user_id'] == $user['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($user['username']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="profile.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 客户列表 -->
            <div class="table-container">
                <h3>客户列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>客户名称</th>
                            <th>类型</th>
                            <th>级别</th>
                            <th>行业</th>
                            <th>地址</th>
                            <th>负责人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($clients)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无客户数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($clients as $client): ?>
                                <tr>
                                    <td><?php echo $client['id']; ?></td>
                                    <td><?php echo htmlspecialchars($client['client_name']); ?></td>
                                    <td><?php echo $client['client_type'] == 1 ? '企业' : '个人'; ?></td>
                                    <td>
                                        <?php
                                        if ($client['client_level'] == 1) echo '<span class="status-vip">VIP</span>';
                                        elseif ($client['client_level'] == 2) echo '<span class="status-normal">普通</span>';
                                        else echo '<span class="status-potential">潜在</span>';
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($client['industry'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($client['address'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($client['owner_name']); ?></td>
                                    <td><?php echo $client['create_time']; ?></td>
                                    <td>
                                        <a href="profile.php?action=edit&id=<?php echo $client['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="client_id" value="<?php echo $client['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除客户 \'<?php echo htmlspecialchars($client['client_name']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>