<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('marketing_activity');

// 记录访问日志
record_log('访问营销活动管理页面');

// 添加/编辑营销活动处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加营销活动
    if ($_POST['action'] == 'add') {
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $budget = isset($_POST['budget']) ? floatval($_POST['budget']) : 0;
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';
        $target_audience = isset($_POST['target_audience']) ? trim($_POST['target_audience']) : '';
        $owner_user_id = isset($_POST['owner_user_id']) ? intval($_POST['owner_user_id']) : $_SESSION['user_id'];

        if (empty($name) || empty($start_date) || empty($end_date)) {
            $error = '请填写完整的活动信息！';
        } else {
            try {
                // 检查活动名称是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM mkt_campaigns WHERE name = ?");
                $stmt->execute([$name]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '活动名称已存在！';
                } else {
                    // 添加活动
                    $stmt = $pdo->prepare("INSERT INTO mkt_campaigns (name, type, budget, start_date, end_date, status, description, target_audience, owner_user_id) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$name, $type, $budget, $start_date, $end_date, $status, $description, $target_audience, $owner_user_id]);

                    if ($result) {
                        record_log("添加营销活动：{$name}");
                        $success = '营销活动添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: activity.php?success=add');
                        exit;
                    } else {
                        $error = '营销活动添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑营销活动
    elseif ($_POST['action'] == 'edit') {
        $campaign_id = isset($_POST['campaign_id']) ? intval($_POST['campaign_id']) : 0;
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $budget = isset($_POST['budget']) ? floatval($_POST['budget']) : 0;
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';
        $target_audience = isset($_POST['target_audience']) ? trim($_POST['target_audience']) : '';
        $owner_user_id = isset($_POST['owner_user_id']) ? intval($_POST['owner_user_id']) : $_SESSION['user_id'];

        if ($campaign_id <= 0 || empty($name) || empty($start_date) || empty($end_date)) {
            $error = '请填写完整的活动信息！';
        } else {
            try {
                // 检查活动名称是否已被其他活动使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM mkt_campaigns WHERE name = ? AND id != ?");
                $stmt->execute([$name, $campaign_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '活动名称已被其他活动使用！';
                } else {
                    // 更新活动信息
                    $stmt = $pdo->prepare("UPDATE mkt_campaigns SET name = ?, type = ?, budget = ?, start_date = ?, end_date = ?, status = ?, description = ?, target_audience = ?, owner_user_id = ? WHERE id = ?");
                    $result = $stmt->execute([$name, $type, $budget, $start_date, $end_date, $status, $description, $target_audience, $owner_user_id, $campaign_id]);

                    if ($result) {
                        record_log("编辑营销活动：{$name}");
                        $success = '营销活动信息更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: activity.php?success=edit');
                        exit;
                    } else {
                        $error = '营销活动信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除营销活动
    elseif ($_POST['action'] == 'delete') {
        $campaign_id = isset($_POST['campaign_id']) ? intval($_POST['campaign_id']) : 0;

        if ($campaign_id <= 0) {
            $error = '无效的活动ID！';
        } else {
            try {
                // 获取活动名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name FROM mkt_campaigns WHERE id = ?");
                $stmt->execute([$campaign_id]);
                $campaign = $stmt->fetch();

                if (!$campaign) {
                    $error = '活动不存在！';
                } else {
                    // 删除活动（级联删除会自动删除相关的渠道和效果记录）
                    $stmt = $pdo->prepare("DELETE FROM mkt_campaigns WHERE id = ?");
                    $result = $stmt->execute([$campaign_id]);

                    if ($result) {
                        record_log("删除营销活动：{$campaign['name']}");
                        $success = '营销活动删除成功！';
                    } else {
                        $error = '营销活动删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有用户（用于选择负责人）
try {
    $stmt = $pdo->query("SELECT id, username FROM sys_users WHERE status = 1 ORDER BY id");
    $users = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取用户列表失败：' . $e->getMessage();
    $users = [];
}

// 获取所有营销活动
try {
    $stmt = $pdo->query("
        SELECT c.*, u.username as owner_name 
        FROM mkt_campaigns c 
        LEFT JOIN sys_users u ON c.owner_user_id = u.id 
        ORDER BY c.id DESC
    ");
    $campaigns = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取营销活动列表失败：' . $e->getMessage();
    $campaigns = [];
}

// 判断是否显示表单
$show_form = false;
$edit_campaign = null;

// 编辑活动时显示表单并获取活动信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM mkt_campaigns WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_campaign = $stmt->fetch();
        if (!$edit_campaign) {
            $error = '营销活动不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取营销活动信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加活动时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '营销活动添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '营销活动信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>营销活动管理</h2>
            <div class="breadcrumb">
                <a href="index.php">市场营销管理</a> &gt; 营销活动管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="activity.php?action=add" class="btn btn-add">添加营销活动</a>
            </div>

            <!-- 添加/编辑营销活动表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_campaign ? '编辑营销活动' : '添加营销活动'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_campaign ? 'edit' : 'add'; ?>">
                        <?php if ($edit_campaign): ?>
                            <input type="hidden" name="campaign_id" value="<?php echo $edit_campaign['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="name">活动名称：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_campaign ? htmlspecialchars($edit_campaign['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="type">活动类型：</label>
                            <select id="type" name="type">
                                <option value="1" <?php echo ($edit_campaign && $edit_campaign['type'] == 1) ? 'selected' : ''; ?>>线上活动</option>
                                <option value="2" <?php echo ($edit_campaign && $edit_campaign['type'] == 2) ? 'selected' : ''; ?>>线下活动</option>
                                <option value="3" <?php echo ($edit_campaign && $edit_campaign['type'] == 3) ? 'selected' : ''; ?>>联合营销</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="budget">预算：</label>
                            <input type="number" id="budget" name="budget" min="0" step="0.01" value="<?php echo $edit_campaign ? htmlspecialchars($edit_campaign['budget']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $edit_campaign ? htmlspecialchars($edit_campaign['start_date']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $edit_campaign ? htmlspecialchars($edit_campaign['end_date']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_campaign && $edit_campaign['status'] == 1) ? 'selected' : ''; ?>>计划中</option>
                                <option value="2" <?php echo ($edit_campaign && $edit_campaign['status'] == 2) ? 'selected' : ''; ?>>执行中</option>
                                <option value="3" <?php echo ($edit_campaign && $edit_campaign['status'] == 3) ? 'selected' : ''; ?>>已结束</option>
                                <option value="4" <?php echo ($edit_campaign && $edit_campaign['status'] == 4) ? 'selected' : ''; ?>>已取消</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="description">活动描述：</label>
                            <textarea id="description" name="description" rows="3"><?php echo $edit_campaign ? htmlspecialchars($edit_campaign['description']) : ''; ?></textarea>
                        </div>

                        <div class="form-group">
                            <label for="target_audience">目标受众：</label>
                            <input type="text" id="target_audience" name="target_audience" value="<?php echo $edit_campaign ? htmlspecialchars($edit_campaign['target_audience']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="owner_user_id">负责人：</label>
                            <select id="owner_user_id" name="owner_user_id">
                                <?php foreach ($users as $user): ?>
                                    <option value="<?php echo $user['id']; ?>" <?php echo ($edit_campaign && $edit_campaign['owner_user_id'] == $user['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($user['username']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="activity.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 营销活动列表 -->
            <div class="table-container">
                <h3>营销活动列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>活动名称</th>
                            <th>类型</th>
                            <th>预算</th>
                            <th>开始日期</th>
                            <th>结束日期</th>
                            <th>状态</th>
                            <th>目标受众</th>
                            <th>负责人</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($campaigns)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无营销活动数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($campaigns as $campaign): ?>
                                <tr>
                                    <td><?php echo $campaign['id']; ?></td>
                                    <td><?php echo htmlspecialchars($campaign['name']); ?></td>
                                    <td>
                                        <?php
                                        if ($campaign['type'] == 1) echo '线上活动';
                                        elseif ($campaign['type'] == 2) echo '线下活动';
                                        else echo '联合营销';
                                        ?>
                                    </td>
                                    <td><?php echo $campaign['budget'] ? number_format($campaign['budget'], 2) : '-'; ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($campaign['start_date'])); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($campaign['end_date'])); ?></td>
                                    <td>
                                        <?php
                                        if ($campaign['status'] == 1) echo '<span class="status-pending">计划中</span>';
                                        elseif ($campaign['status'] == 2) echo '<span class="status-active">执行中</span>';
                                        elseif ($campaign['status'] == 3) echo '<span class="status-inactive">已结束</span>';
                                        elseif ($campaign['status'] == 4) echo '<span class="status-inactive">已取消</span>';
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($campaign['target_audience'] ?: '-'); ?></td>
                                    <td><?php echo htmlspecialchars($campaign['owner_name']); ?></td>
                                    <td>
                                        <a href="activity.php?action=edit&id=<?php echo $campaign['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="campaign_id" value="<?php echo $campaign['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除营销活动 \'<?php echo htmlspecialchars($campaign['name']); ?>\' 吗？这将同时删除相关的渠道和效果数据！');">删除</button>
                                        </form>                                        
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 活动状态说明 -->
            <div class="info-box">
                <h3>营销活动状态说明</h3>
                <ul>
                    <li><strong>计划中</strong>：活动尚在计划阶段，正在准备资源和制定详细方案。</li>
                    <li><strong>执行中</strong>：活动已经开始执行，正在进行中。</li>
                    <li><strong>已结束</strong>：活动已经结束，可以查看效果评估。</li>
                    <li><strong>已取消</strong>：活动因故取消，不再执行。</li>
                </ul>
            </div>
        </div>
    </div>
</body>

</html>