<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('marketing');

// 记录访问日志
record_log('访问市场营销管理页面');

// 获取活动总数
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM mkt_campaigns");
    $campaign_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取活动数据失败：' . $e->getMessage();
    $campaign_count = ['count' => 0];
}

// 获取正在进行中的活动数量
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM mkt_campaigns WHERE status = 2");
    $active_campaign_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取活动数据失败：' . $e->getMessage();
    $active_campaign_count = ['count' => 0];
}

// 获取营销渠道总数
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM mkt_channels");
    $channel_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取渠道数据失败：' . $e->getMessage();
    $channel_count = ['count' => 0];
}

// 获取平均ROI
try {
    $stmt = $pdo->query("SELECT AVG(roi) as avg_roi FROM mkt_results WHERE roi IS NOT NULL");
    $avg_roi = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取营销效果数据失败：' . $e->getMessage();
    $avg_roi = ['avg_roi' => 0];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>市场营销管理</h2>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <h2>营销概览</h2>
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>营销活动总数</h3>
                    <div class="number"><?php echo $campaign_count['count']; ?></div>
                    <div class="desc">所有活动数量</div>
                </div>

                <div class="dashboard-card">
                    <h3>进行中活动</h3>
                    <div class="number"><?php echo $active_campaign_count['count']; ?></div>
                    <div class="desc">正在执行的活动</div>
                </div>

                <div class="dashboard-card">
                    <h3>营销渠道总数</h3>
                    <div class="number"><?php echo $channel_count['count']; ?></div>
                    <div class="desc">所有渠道数量</div>
                </div>

                <div class="dashboard-card">
                    <h3>平均ROI</h3>
                    <div class="number"><?php echo $avg_roi['avg_roi'] ? number_format($avg_roi['avg_roi'], 2) . '%' : '-'; ?></div>
                    <div class="desc">投资回报率平均值</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="activity.php" class="function-link">
                    <h3>营销活动管理</h3>
                </a>
                <a href="email.php" class="function-link">
                    <h3>邮件和短信营销</h3>
                </a>
                <a href="ad.php" class="function-link">
                    <h3>广告投放管理</h3>
                </a>
                <a href="analysis.php" class="function-link">
                    <h3>营销数据分析</h3>
                </a>
            </div>

            <h2>最近营销活动</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>活动名称</th>
                            <th>类型</th>
                            <th>开始日期</th>
                            <th>结束日期</th>
                            <th>状态</th>
                            <th>负责人</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("SELECT c.*, u.username 
                                              FROM mkt_campaigns c
                                              JOIN sys_users u ON c.owner_user_id = u.id 
                                              ORDER BY c.create_time DESC LIMIT 5");
                            $campaigns = $stmt->fetchAll();

                            if (empty($campaigns)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无营销活动记录</td>
                                </tr>
                                <?php else:
                                foreach ($campaigns as $campaign): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($campaign['name']); ?></td>
                                        <td>
                                            <?php
                                            if ($campaign['type'] == 1) echo '线上活动';
                                            elseif ($campaign['type'] == 2) echo '线下活动';
                                            elseif ($campaign['type'] == 3) echo '联合营销';
                                            else echo '其他';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d', strtotime($campaign['start_date'])); ?></td>
                                        <td><?php echo date('Y-m-d', strtotime($campaign['end_date'])); ?></td>
                                        <td>
                                            <?php
                                            if ($campaign['status'] == 1) echo '<span class="status-pending">计划中</span>';
                                            elseif ($campaign['status'] == 2) echo '<span class="status-active">执行中</span>';
                                            elseif ($campaign['status'] == 3) echo '<span class="status-inactive">已结束</span>';
                                            elseif ($campaign['status'] == 4) echo '<span class="status-inactive">已取消</span>';
                                            ?>
                                        </td>
                                        <td><?php echo htmlspecialchars($campaign['username']); ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="6" class="text-center">获取营销活动记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>

            <h2>最近营销渠道活动</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>渠道名称</th>
                            <th>所属活动</th>
                            <th>类型</th>
                            <th>发送时间</th>
                            <th>状态</th>
                            <th>目标/实际数量</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("SELECT ch.*, ca.name as campaign_name 
                                              FROM mkt_channels ch
                                              JOIN mkt_campaigns ca ON ch.campaign_id = ca.id 
                                              ORDER BY ch.create_time DESC LIMIT 5");
                            $channels = $stmt->fetchAll();

                            if (empty($channels)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无营销渠道记录</td>
                                </tr>
                                <?php else:
                                foreach ($channels as $channel): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($channel['name']); ?></td>
                                        <td><?php echo htmlspecialchars($channel['campaign_name']); ?></td>
                                        <td>
                                            <?php
                                            if ($channel['type'] == 1) echo '邮件';
                                            elseif ($channel['type'] == 2) echo '短信';
                                            elseif ($channel['type'] == 3) echo '社交媒体';
                                            elseif ($channel['type'] == 4) echo '搜索引擎';
                                            else echo '其他';
                                            ?>
                                        </td>
                                        <td><?php echo $channel['send_time'] ? date('Y-m-d H:i', strtotime($channel['send_time'])) : '-'; ?></td>
                                        <td>
                                            <?php
                                            if ($channel['status'] == 1) echo '<span class="status-pending">准备中</span>';
                                            elseif ($channel['status'] == 2) echo '<span class="status-active">已发送</span>';
                                            elseif ($channel['status'] == 3) echo '<span class="status-inactive">已完成</span>';
                                            ?>
                                        </td>
                                        <td><?php echo $channel['target_count'] ?: 0; ?>/<?php echo $channel['actual_count'] ?: 0; ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="6" class="text-center">获取营销渠道记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>