<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('report');

// 记录访问日志
record_log('访问数据分析与报表页面');

// 获取报表模板总数
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM report_templates");
    $template_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取报表模板数据失败：' . $e->getMessage();
    $template_count = ['count' => 0];
}

// 获取报表记录总数
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM report_records");
    $report_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取报表记录数据失败：' . $e->getMessage();
    $report_count = ['count' => 0];
}

// 获取仪表盘总数
try {
    $stmt = $pdo->query("SELECT COUNT(*) as count FROM report_dashboards");
    $dashboard_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取仪表盘数据失败：' . $e->getMessage();
    $dashboard_count = ['count' => 0];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>数据分析与报表</h2>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <h2>报表概览</h2>
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>报表模板</h3>
                    <div class="number"><?php echo $template_count['count']; ?></div>
                    <div class="desc">可用的报表模板数量</div>
                </div>

                <div class="dashboard-card">
                    <h3>报表记录</h3>
                    <div class="number"><?php echo $report_count['count']; ?></div>
                    <div class="desc">已生成的报表记录数</div>
                </div>

                <div class="dashboard-card">
                    <h3>仪表盘</h3>
                    <div class="number"><?php echo $dashboard_count['count']; ?></div>
                    <div class="desc">自定义仪表盘数量</div>
                </div>
            </div>

            <h2>数据分析</h2>
            <div class="function-links">
                <a href="client.php" class="function-link">
                    <h3>客户增长分析</h3>
                </a>
                <a href="sales.php" class="function-link">
                    <h3>销售业绩分析</h3>
                </a>
                <a href="marketing.php" class="function-link">
                    <h3>市场营销数据</h3>
                </a>
                <a href="satisfaction.php" class="function-link">
                    <h3>客户满意度分析</h3>
                </a>
                <a href="finance.php" class="function-link">
                    <h3>财务数据分析</h3>
                </a>
                <a href="custom.php" class="function-link">
                    <h3>自定义报表</h3>
                </a>
            </div>

            <h2>最近生成的报表</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>报表标题</th>
                            <th>模板名称</th>
                            <th>创建人</th>
                            <th>创建时间</th>                            
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("SELECT r.*, t.name as template_name, u.username 
                                            FROM report_records r
                                            JOIN report_templates t ON r.template_id = t.id 
                                            JOIN sys_users u ON r.creator_id = u.id 
                                            ORDER BY r.create_time DESC LIMIT 5");
                            $reports = $stmt->fetchAll();

                            if (empty($reports)): ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无报表记录</td>
                                </tr>
                                <?php else:
                                foreach ($reports as $report): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($report['title']); ?></td>
                                        <td><?php echo htmlspecialchars($report['template_name']); ?></td>
                                        <td><?php echo htmlspecialchars($report['username']); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($report['create_time'])); ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="5" class="text-center">获取报表记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>