<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('sales_track');

// 记录访问日志
record_log('访问销售过程跟踪页面');

// 添加/编辑销售过程跟踪记录处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加销售过程跟踪记录
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $type = isset($_POST['type']) ? trim($_POST['type']) : '';
        $subject = isset($_POST['subject']) ? trim($_POST['subject']) : '';
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $interaction_time = isset($_POST['interaction_time']) ? trim($_POST['interaction_time']) : date('Y-m-d H:i:s');
        $user_id = $_SESSION['user_id'];

        if ($client_id <= 0 || empty($subject) || empty($type)) {
            $error = '请填写完整销售过程跟踪信息！';
        } else {
            try {
                // 添加销售过程跟踪记录
                $stmt = $pdo->prepare("INSERT INTO crm_interactions (client_id, user_id, type, subject, content, interaction_time) VALUES (?, ?, ?, ?, ?, ?)");
                $result = $stmt->execute([$client_id, $user_id, $type, $subject, $content, $interaction_time]);

                if ($result) {
                    record_log("添加销售过程跟踪记录：{$subject}");
                    $success = '销售过程跟踪记录添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: track.php?success=add');
                    exit;
                } else {
                    $error = '销售过程跟踪记录添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑销售过程跟踪记录
    elseif ($_POST['action'] == 'edit') {
        $interaction_id = isset($_POST['interaction_id']) ? intval($_POST['interaction_id']) : 0;
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $type = isset($_POST['type']) ? trim($_POST['type']) : '';
        $subject = isset($_POST['subject']) ? trim($_POST['subject']) : '';
        $content = isset($_POST['content']) ? trim($_POST['content']) : '';
        $interaction_time = isset($_POST['interaction_time']) ? trim($_POST['interaction_time']) : date('Y-m-d H:i:s');

        if ($interaction_id <= 0 || $client_id <= 0 || empty($subject) || empty($type)) {
            $error = '请填写完整销售过程跟踪信息！';
        } else {
            try {
                // 更新销售过程跟踪记录信息
                $stmt = $pdo->prepare("UPDATE crm_interactions SET client_id = ?, type = ?, subject = ?, content = ?, interaction_time = ? WHERE id = ?");
                $result = $stmt->execute([$client_id, $type, $subject, $content, $interaction_time, $interaction_id]);

                if ($result) {
                    record_log("编辑销售过程跟踪记录：{$subject}");
                    $success = '销售过程跟踪记录更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: track.php?success=edit');
                    exit;
                } else {
                    $error = '销售过程跟踪记录更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除销售过程跟踪记录
    elseif ($_POST['action'] == 'delete') {
        $interaction_id = isset($_POST['interaction_id']) ? intval($_POST['interaction_id']) : 0;

        if ($interaction_id <= 0) {
            $error = '无效的销售过程跟踪记录ID！';
        } else {
            try {
                // 获取销售过程跟踪记录摘要，用于日志记录
                $stmt = $pdo->prepare("SELECT subject FROM crm_interactions WHERE id = ?");
                $stmt->execute([$interaction_id]);
                $interaction = $stmt->fetch();

                if (!$interaction) {
                    $error = '销售过程跟踪记录不存在！';
                } else {
                    // 删除销售过程跟踪记录
                    $stmt = $pdo->prepare("DELETE FROM crm_interactions WHERE id = ?");
                    $result = $stmt->execute([$interaction_id]);

                    if ($result) {
                        record_log("删除销售过程跟踪记录：{$interaction['subject']}");
                        $success = '销售过程跟踪记录删除成功！';
                    } else {
                        $error = '销售过程跟踪记录删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有客户
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 获取所有联系人
try {
    $stmt = $pdo->query("SELECT id, name, client_id FROM crm_contacts ORDER BY name");
    $contacts = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取联系人列表失败：' . $e->getMessage();
    $contacts = [];
}

// 获取所有销售过程跟踪记录
try {
    $stmt = $pdo->query("
        SELECT i.*, 
               c.client_name, 
               u.username as user_name
        FROM crm_interactions i
        JOIN crm_clients c ON i.client_id = c.id
        JOIN sys_users u ON i.user_id = u.id
        ORDER BY i.interaction_time DESC
    ");
    $interactions = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取销售过程跟踪记录失败：' . $e->getMessage();
    $interactions = [];
}

// 判断是否显示表单
$show_form = false;
$edit_interaction = null;

// 编辑销售过程跟踪记录时显示表单并获取记录信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM crm_interactions WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_interaction = $stmt->fetch();
        if (!$edit_interaction) {
            $error = '销售过程跟踪记录不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取销售过程跟踪记录失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加销售过程跟踪记录时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '销售过程跟踪记录添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '销售过程跟踪记录更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>销售过程跟踪</h2>
            <div class="breadcrumb">
                <a href="index.php">销售管理</a> &gt; 销售过程跟踪
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="track.php?action=add" class="btn btn-add">添加跟踪记录</a>
            </div>

            <!-- 添加/编辑销售过程跟踪记录表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_interaction ? '编辑跟踪记录' : '添加跟踪记录'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_interaction ? 'edit' : 'add'; ?>">
                        <?php if ($edit_interaction): ?>
                            <input type="hidden" name="interaction_id" value="<?php echo $edit_interaction['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="client_id">客户：</label>
                            <select id="client_id" name="client_id" required>
                                <option value="">请选择客户</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>" <?php echo ($edit_interaction && $edit_interaction['client_id'] == $client['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($client['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="type">互动类型：</label>
                            <select id="type" name="type" required>
                                <option value="电话" <?php echo ($edit_interaction && $edit_interaction['type'] == '电话') ? 'selected' : ''; ?>>电话沟通</option>
                                <option value="邮件" <?php echo ($edit_interaction && $edit_interaction['type'] == '邮件') ? 'selected' : ''; ?>>邮件往来</option>
                                <option value="会议" <?php echo ($edit_interaction && $edit_interaction['type'] == '会议') ? 'selected' : ''; ?>>会议</option>
                                <option value="拜访" <?php echo ($edit_interaction && $edit_interaction['type'] == '拜访') ? 'selected' : ''; ?>>客户拜访</option>
                                <option value="其他" <?php echo ($edit_interaction && $edit_interaction['type'] == '其他') ? 'selected' : ''; ?>>其他</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="subject">主题：</label>
                            <input type="text" id="subject" name="subject" value="<?php echo $edit_interaction ? htmlspecialchars($edit_interaction['subject']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="content">详细内容：</label>
                            <textarea id="content" name="content" rows="5"><?php echo $edit_interaction ? htmlspecialchars($edit_interaction['content']) : ''; ?></textarea>
                        </div>

                        <div class="form-group">
                            <label for="interaction_time">互动时间：</label>
                            <input type="datetime-local" id="interaction_time" name="interaction_time" value="<?php echo $edit_interaction ? date('Y-m-d\TH:i', strtotime($edit_interaction['interaction_time'])) : date('Y-m-d\TH:i'); ?>" required>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="track.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 销售过程跟踪记录列表 -->
            <div class="table-container">
                <h3>销售过程跟踪记录</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>客户名称</th>
                            <th>互动类型</th>
                            <th>主题</th>
                            <th>记录人</th>
                            <th>互动时间</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($interactions)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无销售过程跟踪记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($interactions as $interaction): ?>
                                <tr>
                                    <td><?php echo $interaction['id']; ?></td>
                                    <td><?php echo htmlspecialchars($interaction['client_name']); ?></td>
                                    <td><?php echo htmlspecialchars($interaction['type']); ?></td>
                                    <td><?php echo htmlspecialchars($interaction['subject']); ?></td>
                                    <td><?php echo htmlspecialchars($interaction['user_name']); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($interaction['interaction_time'])); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($interaction['create_time'])); ?></td>
                                    <td>
                                        <a href="track.php?action=edit&id=<?php echo $interaction['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="interaction_id" value="<?php echo $interaction['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除这条跟踪记录吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>