<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('task_reminder');

// 记录访问日志
record_log('访问提醒通知页面');

// 处理提交的操作
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 标记提醒为已读
    if ($_POST['action'] == 'mark_read') {
        $reminder_id = isset($_POST['reminder_id']) ? intval($_POST['reminder_id']) : 0;

        if ($reminder_id <= 0) {
            $error = '无效的提醒ID！';
        } else {
            try {
                $stmt = $pdo->prepare("SELECT title FROM task_reminders WHERE id = ? AND user_id = ?");
                $stmt->execute([$reminder_id, $_SESSION['user_id']]);
                $reminder = $stmt->fetch();

                if (!$reminder) {
                    $error = '提醒不存在或无权限操作！';
                } else {
                    $stmt = $pdo->prepare("UPDATE task_reminders SET status = 2 WHERE id = ? AND user_id = ?");
                    $result = $stmt->execute([$reminder_id, $_SESSION['user_id']]);

                    if ($result) {
                        record_log("标记提醒为已读：{$reminder['title']}");
                        $success = '提醒已标记为已读！';
                    } else {
                        $error = '操作失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 标记所有提醒为已读
    elseif ($_POST['action'] == 'mark_all_read') {
        try {
            $stmt = $pdo->prepare("UPDATE task_reminders SET status = 2 WHERE user_id = ? AND status = 1");
            $result = $stmt->execute([$_SESSION['user_id']]);

            if ($result) {
                record_log("标记所有提醒为已读");
                $success = '所有提醒已标记为已读！';
            } else {
                $error = '操作失败！';
            }
        } catch (PDOException $e) {
            $error = '系统错误：' . $e->getMessage();
        }
    }

    // 删除提醒
    elseif ($_POST['action'] == 'delete') {
        $reminder_id = isset($_POST['reminder_id']) ? intval($_POST['reminder_id']) : 0;

        if ($reminder_id <= 0) {
            $error = '无效的提醒ID！';
        } else {
            try {
                $stmt = $pdo->prepare("SELECT title FROM task_reminders WHERE id = ? AND user_id = ?");
                $stmt->execute([$reminder_id, $_SESSION['user_id']]);
                $reminder = $stmt->fetch();

                if (!$reminder) {
                    $error = '提醒不存在或无权限删除！';
                } else {
                    $stmt = $pdo->prepare("DELETE FROM task_reminders WHERE id = ? AND user_id = ?");
                    $result = $stmt->execute([$reminder_id, $_SESSION['user_id']]);

                    if ($result) {
                        record_log("删除提醒：{$reminder['title']}");
                        $success = '提醒删除成功！';
                    } else {
                        $error = '提醒删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取筛选条件
$filter_type = isset($_GET['type']) ? intval($_GET['type']) : 0;
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0;
$filter_where = "WHERE user_id = {$_SESSION['user_id']}";

if ($filter_type > 0) {
    $filter_where .= " AND type = {$filter_type}";
}

if ($filter_status > 0) {
    $filter_where .= " AND status = {$filter_status}";
}

// 获取所有提醒
try {
    $stmt = $pdo->query("SELECT * FROM task_reminders {$filter_where} ORDER BY status ASC, remind_time DESC");
    $reminders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取提醒列表失败：' . $e->getMessage();
    $reminders = [];
}

// 获取未读提醒数量
try {
    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM task_reminders WHERE user_id = ? AND status = 1");
    $stmt->execute([$_SESSION['user_id']]);
    $unread_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取未读提醒数量失败：' . $e->getMessage();
    $unread_count = ['count' => 0];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>提醒通知</h2>
            <div class="breadcrumb">
                <a href="index.php">任务与日程管理</a> &gt; 提醒通知
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <form method="post" action="" class="inline-form">
                    <input type="hidden" name="action" value="mark_all_read">
                    <button type="submit" class="btn btn-primary" <?php echo $unread_count['count'] > 0 ? '' : 'disabled'; ?>>
                        标记所有为已读
                    </button>
                </form>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="type">类型：</label>
                            <select id="type" name="type">
                                <option value="0">全部类型</option>
                                <option value="1" <?php echo $filter_type == 1 ? 'selected' : ''; ?>>系统</option>
                                <option value="2" <?php echo $filter_type == 2 ? 'selected' : ''; ?>>邮件</option>
                                <option value="3" <?php echo $filter_type == 3 ? 'selected' : ''; ?>>短信</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="0">全部状态</option>
                                <option value="1" <?php echo $filter_status == 1 ? 'selected' : ''; ?>>未读</option>
                                <option value="2" <?php echo $filter_status == 2 ? 'selected' : ''; ?>>已读</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="notify.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <!-- 提醒列表 -->
            <div class="table-container">
                <h3>提醒列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>标题</th>
                            <th>类型</th>
                            <th>关联项目</th>
                            <th>提醒时间</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($reminders)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无提醒通知</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($reminders as $reminder): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($reminder['title']); ?></td>
                                    <td>
                                        <?php
                                        if ($reminder['type'] == 1) echo '系统';
                                        elseif ($reminder['type'] == 2) echo '邮件';
                                        else echo '短信';
                                        ?>
                                    </td>
                                    <td>
                                        <?php
                                        if ($reminder['related_type'] == 'todo') echo '待办事项';
                                        elseif ($reminder['related_type'] == 'schedule') echo '日程安排';
                                        elseif ($reminder['related_type'] == 'contract') echo '合同';
                                        elseif ($reminder['related_type'] == 'client') echo '客户';
                                        else echo '-';
                                        ?>
                                    </td>
                                    <td>
                                        <?php
                                        $remind_time = strtotime($reminder['remind_time']);
                                        $now = time();

                                        echo date('Y-m-d H:i', $remind_time);

                                        if ($reminder['status'] == 1) {
                                            if ($remind_time <= $now) {
                                                echo ' <span style="color: red;">(已到时间)</span>';
                                            } elseif ($remind_time - $now < 3600) { // 1小时内
                                                echo ' <span style="color: orange;">(即将到时)</span>';
                                            }
                                        }
                                        ?>
                                    </td>
                                    <td>
                                        <?php
                                        if ($reminder['status'] == 1) {
                                            echo '<span style="color: #ffc107;">未读</span>';
                                        } else {
                                            echo '<span style="color: #28a745;">已读</span>';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($reminder['create_time'])); ?></td>
                                    <td>
                                        <?php if ($reminder['status'] == 1): ?>
                                            <form method="post" action="" style="display:inline;">
                                                <input type="hidden" name="action" value="mark_read">
                                                <input type="hidden" name="reminder_id" value="<?php echo $reminder['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-success">标记已读</button>
                                            </form>
                                        <?php endif; ?>

                                        <?php if ($reminder['related_type'] == 'todo' && $reminder['related_id']): ?>
                                            <a href="todo.php?action=edit&id=<?php echo $reminder['related_id']; ?>" class="btn btn-sm btn-primary">查看任务</a>
                                        <?php elseif ($reminder['related_type'] == 'schedule' && $reminder['related_id']): ?>
                                            <a href="schedule.php?action=edit&id=<?php echo $reminder['related_id']; ?>" class="btn btn-sm btn-primary">查看日程</a>
                                        <?php endif; ?>

                                        <form method="post" action="" style="display:inline;">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="reminder_id" value="<?php echo $reminder['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此提醒通知吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 提示信息 -->
            <div class="info-box">
                <h3>关于提醒通知</h3>
                <p>提醒通知功能帮助您：</p>
                <ul>
                    <li><strong>及时提醒</strong>：系统会在设定的时间自动提醒您关注相关事项。</li>
                    <li><strong>多种类型</strong>：支持系统内部通知、邮件提醒和短信提醒等多种方式。</li>
                    <li><strong>关联功能</strong>：提醒可以关联到待办事项、日程安排、客户等，方便您直接查看详情。</li>
                    <li><strong>状态管理</strong>：您可以标记提醒为已读，也可以删除不再需要的提醒。</li>
                </ul>
                <p>提示：及时查看并处理您的提醒通知，避免错过重要事项。</p>
            </div>
        </div>
    </div>
</body>

</html>