<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('task_schedule');

// 记录访问日志
record_log('访问日程安排页面');

// 添加/编辑日程处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加日程
    if ($_POST['action'] == 'add') {
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : null;
        $start_time = isset($_POST['start_time']) ? trim($_POST['start_time']) : '';
        $end_time = isset($_POST['end_time']) ? trim($_POST['end_time']) : '';
        $location = isset($_POST['location']) ? trim($_POST['location']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($title) || empty($start_time) || empty($end_time)) {
            $error = '请填写完整日程信息！';
        } else {
            try {
                // 添加日程
                $stmt = $pdo->prepare("INSERT INTO task_schedules (title, type, client_id, start_time, end_time, location, status, user_id) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
                $result = $stmt->execute([$title, $type, $client_id ?: null, $start_time, $end_time, $location, $status, $_SESSION['user_id']]);

                if ($result) {
                    record_log("添加日程：{$title}");
                    $success = '日程添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: schedule.php?success=add');
                    exit;
                } else {
                    $error = '日程添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑日程
    elseif ($_POST['action'] == 'edit') {
        $schedule_id = isset($_POST['schedule_id']) ? intval($_POST['schedule_id']) : 0;
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : null;
        $start_time = isset($_POST['start_time']) ? trim($_POST['start_time']) : '';
        $end_time = isset($_POST['end_time']) ? trim($_POST['end_time']) : '';
        $location = isset($_POST['location']) ? trim($_POST['location']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($schedule_id <= 0 || empty($title) || empty($start_time) || empty($end_time)) {
            $error = '请填写完整日程信息！';
        } else {
            try {
                // 更新日程信息
                $stmt = $pdo->prepare("UPDATE task_schedules SET title = ?, type = ?, client_id = ?, start_time = ?, end_time = ?, location = ?, status = ? WHERE id = ? AND user_id = ?");
                $result = $stmt->execute([$title, $type, $client_id ?: null, $start_time, $end_time, $location, $status, $schedule_id, $_SESSION['user_id']]);

                if ($result) {
                    record_log("编辑日程：{$title}");
                    $success = '日程信息更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: schedule.php?success=edit');
                    exit;
                } else {
                    $error = '日程信息更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除日程
    elseif ($_POST['action'] == 'delete') {
        $schedule_id = isset($_POST['schedule_id']) ? intval($_POST['schedule_id']) : 0;

        if ($schedule_id <= 0) {
            $error = '无效的日程ID！';
        } else {
            try {
                // 获取日程标题，用于日志记录
                $stmt = $pdo->prepare("SELECT title FROM task_schedules WHERE id = ? AND user_id = ?");
                $stmt->execute([$schedule_id, $_SESSION['user_id']]);
                $schedule = $stmt->fetch();

                if (!$schedule) {
                    $error = '日程不存在或无权限删除！';
                } else {
                    // 删除日程
                    $stmt = $pdo->prepare("DELETE FROM task_schedules WHERE id = ? AND user_id = ?");
                    $result = $stmt->execute([$schedule_id, $_SESSION['user_id']]);

                    if ($result) {
                        // 删除相关提醒
                        $stmt = $pdo->prepare("DELETE FROM task_reminders WHERE related_id = ? AND related_type = 'schedule'");
                        $stmt->execute([$schedule_id]);

                        record_log("删除日程：{$schedule['title']}");
                        $success = '日程删除成功！';
                    } else {
                        $error = '日程删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取筛选条件
$filter_type = isset($_GET['type']) ? intval($_GET['type']) : 0;
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0;
$filter_month = isset($_GET['month']) ? $_GET['month'] : date('Y-m');
$filter_where = "WHERE user_id = {$_SESSION['user_id']}";

if ($filter_type > 0) {
    $filter_where .= " AND type = {$filter_type}";
}

if ($filter_status > 0) {
    $filter_where .= " AND status = {$filter_status}";
}

if (!empty($filter_month)) {
    $month_start = $filter_month . '-01';
    $month_end = date('Y-m-t', strtotime($month_start));
    $filter_where .= " AND (
        (DATE(start_time) BETWEEN '{$month_start}' AND '{$month_end}') OR 
        (DATE(end_time) BETWEEN '{$month_start}' AND '{$month_end}') OR 
        (DATE(start_time) <= '{$month_start}' AND DATE(end_time) >= '{$month_end}')
    )";
}

// 获取所有日程
try {
    $stmt = $pdo->query("
        SELECT s.*, c.client_name 
        FROM task_schedules s
        LEFT JOIN crm_clients c ON s.client_id = c.id
        {$filter_where}
        ORDER BY s.start_time DESC
    ");
    $schedules = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取日程列表失败：' . $e->getMessage();
    $schedules = [];
}

// 获取客户列表用于选择
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 判断是否显示表单
$show_form = false;
$edit_schedule = null;

// 编辑日程时显示表单并获取日程信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM task_schedules WHERE id = ? AND user_id = ?");
        $stmt->execute([$edit_id, $_SESSION['user_id']]);
        $edit_schedule = $stmt->fetch();
        if (!$edit_schedule) {
            $error = '日程不存在或无权限编辑！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取日程信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加日程时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '日程添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '日程信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>日程安排</h2>
            <div class="breadcrumb">
                <a href="index.php">任务与日程管理</a> &gt; 日程安排
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="schedule.php?action=add" class="btn btn-add">添加日程</a>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>日程筛选</h3>
                <form method="get" action="">
                    <div class="form-group">
                        <label for="type">日程类型：</label>
                        <select id="type" name="type">
                            <option value="0">全部类型</option>
                            <option value="1" <?php echo $filter_type == 1 ? 'selected' : ''; ?>>拜访</option>
                            <option value="2" <?php echo $filter_type == 2 ? 'selected' : ''; ?>>会议</option>
                            <option value="3" <?php echo $filter_type == 3 ? 'selected' : ''; ?>>其他</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="status">状态：</label>
                        <select id="status" name="status">
                            <option value="0">全部状态</option>
                            <option value="1" <?php echo $filter_status == 1 ? 'selected' : ''; ?>>未完成</option>
                            <option value="2" <?php echo $filter_status == 2 ? 'selected' : ''; ?>>已完成</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="month">月份：</label>
                        <input type="month" id="month" name="month" value="<?php echo $filter_month; ?>">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">筛选</button>
                        <a href="schedule.php" class="btn btn-secondary">重置</a>
                    </div>
                </form>
            </div>

            <!-- 添加/编辑日程表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_schedule ? '编辑日程' : '添加日程'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_schedule ? 'edit' : 'add'; ?>">
                        <?php if ($edit_schedule): ?>
                            <input type="hidden" name="schedule_id" value="<?php echo $edit_schedule['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="title">日程标题：</label>
                            <input type="text" id="title" name="title" value="<?php echo $edit_schedule ? htmlspecialchars($edit_schedule['title']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="type">日程类型：</label>
                            <select id="type" name="type">
                                <option value="1" <?php echo ($edit_schedule && $edit_schedule['type'] == 1) ? 'selected' : ''; ?>>拜访</option>
                                <option value="2" <?php echo ($edit_schedule && $edit_schedule['type'] == 2) ? 'selected' : ''; ?>>会议</option>
                                <option value="3" <?php echo ($edit_schedule && $edit_schedule['type'] == 3) ? 'selected' : ''; ?>>其他</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="client_id">关联客户：</label>
                            <select id="client_id" name="client_id">
                                <option value="">-- 不关联客户 --</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>" <?php echo ($edit_schedule && $edit_schedule['client_id'] == $client['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($client['client_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="start_time">开始时间：</label>
                            <input type="datetime-local" id="start_time" name="start_time" value="<?php echo $edit_schedule ? date('Y-m-d\TH:i', strtotime($edit_schedule['start_time'])) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="end_time">结束时间：</label>
                            <input type="datetime-local" id="end_time" name="end_time" value="<?php echo $edit_schedule ? date('Y-m-d\TH:i', strtotime($edit_schedule['end_time'])) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="location">地点：</label>
                            <input type="text" id="location" name="location" value="<?php echo $edit_schedule ? htmlspecialchars($edit_schedule['location']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_schedule && $edit_schedule['status'] == 1) ? 'selected' : ''; ?>>未完成</option>
                                <option value="2" <?php echo ($edit_schedule && $edit_schedule['status'] == 2) ? 'selected' : ''; ?>>已完成</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="schedule.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 日程列表 -->
            <div class="table-container">
                <h3>日程列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>标题</th>
                            <th>类型</th>
                            <th>关联客户</th>
                            <th>开始时间</th>
                            <th>结束时间</th>
                            <th>地点</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($schedules)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无日程数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($schedules as $schedule): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($schedule['title']); ?></td>
                                    <td>
                                        <?php
                                        if ($schedule['type'] == 1) echo '拜访';
                                        elseif ($schedule['type'] == 2) echo '会议';
                                        else echo '其他';
                                        ?>
                                    </td>
                                    <td><?php echo $schedule['client_name'] ? htmlspecialchars($schedule['client_name']) : '-'; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($schedule['start_time'])); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($schedule['end_time'])); ?></td>
                                    <td><?php echo htmlspecialchars($schedule['location'] ?: '-'); ?></td>
                                    <td>
                                        <?php
                                        if ($schedule['status'] == 1) echo '<span class="status-pending">未完成</span>';
                                        else echo '<span class="status-active">已完成</span>';
                                        ?>
                                    </td>
                                    <td>
                                        <a href="schedule.php?action=edit&id=<?php echo $schedule['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="schedule_id" value="<?php echo $schedule['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除日程 \'<?php echo htmlspecialchars($schedule['title']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 提示信息 -->
            <div class="info-box">
                <h3>关于日程安排</h3>
                <p>日程安排功能帮助您：</p>
                <ul>
                    <li><strong>规划工作时间</strong>：记录客户拜访、内部会议等日程安排。</li>
                    <li><strong>关联客户信息</strong>：将日程与特定客户关联，方便查看客户互动历史。</li>
                    <li><strong>状态跟踪</strong>：标记日程完成状态，确保所有工作按计划执行。</li>
                    <li><strong>按月查看</strong>：通过筛选器查看特定月份的日程安排。</li>
                </ul>
                <p>提示：添加重要日程后，系统会自动创建提醒，确保您不会错过重要安排。</p>
            </div>
        </div>
    </div>
</body>

</html>