<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('task_todo');

// 记录访问日志
record_log('访问待办事项页面');

// 添加/编辑待办事项处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加待办事项
    if ($_POST['action'] == 'add') {
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $priority = isset($_POST['priority']) ? intval($_POST['priority']) : 2;
        $end_time = isset($_POST['end_time']) ? trim($_POST['end_time']) : null;
        $team_id = isset($_POST['team_id']) && !empty($_POST['team_id']) ? intval($_POST['team_id']) : null;
        $add_reminder = isset($_POST['add_reminder']) ? (bool)$_POST['add_reminder'] : false;
        $reminder_time = isset($_POST['reminder_time']) ? trim($_POST['reminder_time']) : '';

        if (empty($title)) {
            $error = '请填写待办事项标题！';
        } else {
            try {
                // 添加待办事项
                $stmt = $pdo->prepare("INSERT INTO task_todos (title, type, priority, status, end_time, user_id, team_id) VALUES (?, ?, ?, 1, ?, ?, ?)");
                $result = $stmt->execute([$title, $type, $priority, $end_time ?: null, $_SESSION['user_id'], $team_id]);

                if ($result) {
                    $todo_id = $pdo->lastInsertId();
                    record_log("添加待办事项：{$title}");

                    // 如果勾选了添加提醒
                    if ($add_reminder && !empty($reminder_time)) {
                        $reminder_title = "待办事项提醒：{$title}";
                        $stmt = $pdo->prepare("INSERT INTO task_reminders (title, type, related_id, related_type, remind_time, user_id, status) VALUES (?, 1, ?, 'todo', ?, ?, 1)");
                        $stmt->execute([$reminder_title, $todo_id, $reminder_time, $_SESSION['user_id']]);
                        record_log("添加待办事项提醒：{$reminder_title}");
                    }

                    $success = '待办事项添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: todo.php?success=add');
                    exit;
                } else {
                    $error = '待办事项添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑待办事项
    elseif ($_POST['action'] == 'edit') {
        $todo_id = isset($_POST['todo_id']) ? intval($_POST['todo_id']) : 0;
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $type = isset($_POST['type']) ? intval($_POST['type']) : 1;
        $priority = isset($_POST['priority']) ? intval($_POST['priority']) : 2;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $end_time = isset($_POST['end_time']) ? trim($_POST['end_time']) : null;
        $team_id = isset($_POST['team_id']) && !empty($_POST['team_id']) ? intval($_POST['team_id']) : null;
        $add_reminder = isset($_POST['add_reminder']) ? (bool)$_POST['add_reminder'] : false;
        $reminder_time = isset($_POST['reminder_time']) ? trim($_POST['reminder_time']) : '';

        if ($todo_id <= 0 || empty($title)) {
            $error = '请填写完整待办事项信息！';
        } else {
            try {
                // 更新待办事项信息
                $stmt = $pdo->prepare("UPDATE task_todos SET title = ?, type = ?, priority = ?, status = ?, end_time = ?, team_id = ? WHERE id = ? AND user_id = ?");
                $result = $stmt->execute([$title, $type, $priority, $status, $end_time ?: null, $team_id, $todo_id, $_SESSION['user_id']]);

                if ($result) {
                    record_log("编辑待办事项：{$title}");

                    // 处理提醒
                    if ($add_reminder && !empty($reminder_time)) {
                        // 检查是否已有提醒
                        $stmt = $pdo->prepare("SELECT id FROM task_reminders WHERE related_id = ? AND related_type = 'todo' AND user_id = ?");
                        $stmt->execute([$todo_id, $_SESSION['user_id']]);
                        $existing_reminder = $stmt->fetch();

                        $reminder_title = "待办事项提醒：{$title}";
                        if ($existing_reminder) {
                            // 更新现有提醒
                            $stmt = $pdo->prepare("UPDATE task_reminders SET title = ?, remind_time = ?, status = 1 WHERE id = ?");
                            $stmt->execute([$reminder_title, $reminder_time, $existing_reminder['id']]);
                        } else {
                            // 添加新提醒
                            $stmt = $pdo->prepare("INSERT INTO task_reminders (title, type, related_id, related_type, remind_time, user_id, status) VALUES (?, 1, ?, 'todo', ?, ?, 1)");
                            $stmt->execute([$reminder_title, $todo_id, $reminder_time, $_SESSION['user_id']]);
                        }
                    }

                    $success = '待办事项信息更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: todo.php?success=edit');
                    exit;
                } else {
                    $error = '待办事项信息更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除待办事项
    elseif ($_POST['action'] == 'delete') {
        $todo_id = isset($_POST['todo_id']) ? intval($_POST['todo_id']) : 0;

        if ($todo_id <= 0) {
            $error = '无效的待办事项ID！';
        } else {
            try {
                // 获取待办事项标题，用于日志记录
                $stmt = $pdo->prepare("SELECT title FROM task_todos WHERE id = ? AND user_id = ?");
                $stmt->execute([$todo_id, $_SESSION['user_id']]);
                $todo = $stmt->fetch();

                if (!$todo) {
                    $error = '待办事项不存在或无权限删除！';
                } else {
                    // 删除待办事项
                    $stmt = $pdo->prepare("DELETE FROM task_todos WHERE id = ? AND user_id = ?");
                    $result = $stmt->execute([$todo_id, $_SESSION['user_id']]);

                    if ($result) {
                        // 删除相关提醒
                        $stmt = $pdo->prepare("DELETE FROM task_reminders WHERE related_id = ? AND related_type = 'todo'");
                        $stmt->execute([$todo_id]);

                        record_log("删除待办事项：{$todo['title']}");
                        $success = '待办事项删除成功！';
                    } else {
                        $error = '待办事项删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 完成待办事项
    elseif ($_POST['action'] == 'complete') {
        $todo_id = isset($_POST['todo_id']) ? intval($_POST['todo_id']) : 0;

        if ($todo_id <= 0) {
            $error = '无效的待办事项ID！';
        } else {
            try {
                // 获取待办事项标题，用于日志记录
                $stmt = $pdo->prepare("SELECT title FROM task_todos WHERE id = ? AND user_id = ?");
                $stmt->execute([$todo_id, $_SESSION['user_id']]);
                $todo = $stmt->fetch();

                if (!$todo) {
                    $error = '待办事项不存在或无权限操作！';
                } else {
                    // 更新待办事项状态为已完成
                    $stmt = $pdo->prepare("UPDATE task_todos SET status = 2 WHERE id = ? AND user_id = ?");
                    $result = $stmt->execute([$todo_id, $_SESSION['user_id']]);

                    if ($result) {
                        record_log("完成待办事项：{$todo['title']}");
                        $success = '待办事项已标记为完成！';
                    } else {
                        $error = '操作失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取筛选条件
$filter_type = isset($_GET['type']) ? intval($_GET['type']) : 0;
$filter_priority = isset($_GET['priority']) ? intval($_GET['priority']) : 0;
$filter_status = isset($_GET['status']) ? intval($_GET['status']) : 0;
$filter_where = "WHERE user_id = {$_SESSION['user_id']}";

if ($filter_type > 0) {
    $filter_where .= " AND type = {$filter_type}";
}

if ($filter_priority > 0) {
    $filter_where .= " AND priority = {$filter_priority}";
}

if ($filter_status > 0) {
    $filter_where .= " AND status = {$filter_status}";
}

// 获取所有待办事项
try {
    $stmt = $pdo->query("
        SELECT t.*, p.team_name 
        FROM task_todos t
        LEFT JOIN perf_teams p ON t.team_id = p.id
        {$filter_where}
        ORDER BY t.status ASC, t.priority DESC, t.end_time ASC
    ");
    $todos = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取待办事项列表失败：' . $e->getMessage();
    $todos = [];
}

// 获取团队列表用于选择
try {
    $stmt = $pdo->prepare("
        SELECT id, team_name 
        FROM perf_teams 
        WHERE leader_id = ? OR members LIKE ?
        ORDER BY team_name
    ");
    $stmt->execute([$_SESSION['user_id'], '%,' . $_SESSION['user_id'] . ',%']);
    $teams = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取团队列表失败：' . $e->getMessage();
    $teams = [];
}

// 判断是否显示表单
$show_form = false;
$edit_todo = null;

// 编辑待办事项时显示表单并获取信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM task_todos WHERE id = ? AND user_id = ?");
        $stmt->execute([$edit_id, $_SESSION['user_id']]);
        $edit_todo = $stmt->fetch();
        if (!$edit_todo) {
            $error = '待办事项不存在或无权限编辑！';
            $show_form = false;
        } else {
            // 检查是否有关联的提醒
            $stmt = $pdo->prepare("SELECT * FROM task_reminders WHERE related_id = ? AND related_type = 'todo' AND user_id = ?");
            $stmt->execute([$edit_id, $_SESSION['user_id']]);
            $reminder = $stmt->fetch();
            if ($reminder) {
                $edit_todo['has_reminder'] = true;
                $edit_todo['reminder_time'] = $reminder['remind_time'];
            } else {
                $edit_todo['has_reminder'] = false;
            }
        }
    } catch (PDOException $e) {
        $error = '获取待办事项信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加待办事项时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '待办事项添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '待办事项信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>待办事项</h2>
            <div class="breadcrumb">
                <a href="index.php">任务与日程管理</a> &gt; 待办事项
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="todo.php?action=add" class="btn btn-add">添加待办事项</a>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="form-group">
                        <label for="type">类型：</label>
                        <select id="type" name="type">
                            <option value="0">全部类型</option>
                            <option value="1" <?php echo $filter_type == 1 ? 'selected' : ''; ?>>个人</option>
                            <option value="2" <?php echo $filter_type == 2 ? 'selected' : ''; ?>>团队</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="priority">优先级：</label>
                        <select id="priority" name="priority">
                            <option value="0">全部优先级</option>
                            <option value="3" <?php echo $filter_priority == 3 ? 'selected' : ''; ?>>高</option>
                            <option value="2" <?php echo $filter_priority == 2 ? 'selected' : ''; ?>>中</option>
                            <option value="1" <?php echo $filter_priority == 1 ? 'selected' : ''; ?>>低</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="status">状态：</label>
                        <select id="status" name="status">
                            <option value="0">全部状态</option>
                            <option value="1" <?php echo $filter_status == 1 ? 'selected' : ''; ?>>待处理</option>
                            <option value="2" <?php echo $filter_status == 2 ? 'selected' : ''; ?>>已完成</option>
                        </select>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">筛选</button>
                        <a href="todo.php" class="btn btn-secondary">重置</a>
                    </div>
                </form>
            </div>

            <!-- 添加/编辑待办事项表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_todo ? '编辑待办事项' : '添加待办事项'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_todo ? 'edit' : 'add'; ?>">
                        <?php if ($edit_todo): ?>
                            <input type="hidden" name="todo_id" value="<?php echo $edit_todo['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="title">标题：</label>
                            <input type="text" id="title" name="title" value="<?php echo $edit_todo ? htmlspecialchars($edit_todo['title']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="type">类型：</label>
                            <select id="type" name="type">
                                <option value="1" <?php echo ($edit_todo && $edit_todo['type'] == 1) ? 'selected' : ''; ?>>个人</option>
                                <option value="2" <?php echo ($edit_todo && $edit_todo['type'] == 2) ? 'selected' : ''; ?>>团队</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="priority">优先级：</label>
                            <select id="priority" name="priority">
                                <option value="3" <?php echo ($edit_todo && $edit_todo['priority'] == 3) ? 'selected' : ''; ?>>高</option>
                                <option value="2" <?php echo ($edit_todo && $edit_todo['priority'] == 2) ? 'selected' : ($edit_todo ? '' : 'selected'); ?>>中</option>
                                <option value="1" <?php echo ($edit_todo && $edit_todo['priority'] == 1) ? 'selected' : ''; ?>>低</option>
                            </select>
                        </div>

                        <?php if ($edit_todo): ?>
                            <div class="form-group">
                                <label for="status">状态：</label>
                                <select id="status" name="status">
                                    <option value="1" <?php echo ($edit_todo && $edit_todo['status'] == 1) ? 'selected' : ''; ?>>待处理</option>
                                    <option value="2" <?php echo ($edit_todo && $edit_todo['status'] == 2) ? 'selected' : ''; ?>>已完成</option>
                                </select>
                            </div>
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="end_time">截止时间：</label>
                            <input type="datetime-local" id="end_time" name="end_time" value="<?php echo $edit_todo && $edit_todo['end_time'] ? date('Y-m-d\TH:i', strtotime($edit_todo['end_time'])) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="team_id">所属团队：</label>
                            <select id="team_id" name="team_id">
                                <option value="">-- 无团队（个人任务）--</option>
                                <?php foreach ($teams as $team): ?>
                                    <option value="<?php echo $team['id']; ?>" <?php echo ($edit_todo && $edit_todo['team_id'] == $team['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($team['team_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label>
                                <input type="checkbox" name="add_reminder" value="1" <?php echo ($edit_todo && $edit_todo['has_reminder']) ? 'checked' : ''; ?>>
                                添加提醒
                            </label>
                        </div>

                        <div class="form-group">
                            <label for="reminder_time">提醒时间：</label>
                            <input type="datetime-local" id="reminder_time" name="reminder_time" value="<?php echo $edit_todo && isset($edit_todo['reminder_time']) ? date('Y-m-d\TH:i', strtotime($edit_todo['reminder_time'])) : ''; ?>">
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="todo.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 待办事项列表 -->
            <div class="table-container">
                <h3>待办事项列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>标题</th>
                            <th>类型</th>
                            <th>优先级</th>
                            <th>截止时间</th>
                            <th>所属团队</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($todos)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无待办事项</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($todos as $todo): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($todo['title']); ?></td>
                                    <td>
                                        <?php echo $todo['type'] == 1 ? '个人' : '团队'; ?>
                                    </td>
                                    <td>
                                        <?php
                                        if ($todo['priority'] == 3) echo '<span style="color: red;">高</span>';
                                        elseif ($todo['priority'] == 2) echo '<span style="color: orange;">中</span>';
                                        else echo '<span style="color: green;">低</span>';
                                        ?>
                                    </td>
                                    <td>
                                        <?php
                                        if ($todo['end_time']) {
                                            $end_time = strtotime($todo['end_time']);
                                            $now = time();
                                            $one_day = 86400; // 24小时的秒数

                                            echo date('Y-m-d H:i', $end_time);

                                            // 如果任务未完成且快到期或已过期，显示提示
                                            if ($todo['status'] == 1) {
                                                if ($end_time < $now) {
                                                    echo ' <span style="color: red;">(已过期)</span>';
                                                } elseif ($end_time - $now < $one_day) {
                                                    echo ' <span style="color: orange;">(即将到期)</span>';
                                                }
                                            }
                                        } else {
                                            echo '无截止时间';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo $todo['team_name'] ? htmlspecialchars($todo['team_name']) : '-'; ?></td>
                                    <td>
                                        <?php
                                        if ($todo['status'] == 1) echo '<span class="status-pending">待处理</span>';
                                        else echo '<span class="status-active">已完成</span>';
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($todo['create_time'])); ?></td>
                                    <td>
                                        <?php if ($todo['status'] == 1): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="complete">
                                                <input type="hidden" name="todo_id" value="<?php echo $todo['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-success" onclick="return confirm('确定要标记该待办事项为已完成吗？');">完成</button>
                                            </form>
                                        <?php endif; ?>
                                        <a href="todo.php?action=edit&id=<?php echo $todo['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="todo_id" value="<?php echo $todo['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除待办事项 \'<?php echo htmlspecialchars($todo['title']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 提示信息 -->
            <div class="info-box">
                <h3>关于待办事项</h3>
                <p>待办事项功能帮助您：</p>
                <ul>
                    <li><strong>有效管理任务</strong>：记录需要完成的工作，避免遗漏重要事项。</li>
                    <li><strong>设置优先级</strong>：为任务分配高、中、低优先级，确保重要任务优先处理。</li>
                    <li><strong>设置截止时间</strong>：为任务设定完成期限，帮助您合理安排工作计划。</li>
                    <li><strong>设置提醒</strong>：为重要待办事项设置提醒，避免错过重要任务。</li>
                    <li><strong>团队协作</strong>：可将任务与团队关联，便于团队协作和任务跟踪。</li>
                </ul>
                <p>提示：优先处理高优先级和即将到期的任务，及时标记已完成的任务。</p>
            </div>
        </div>
    </div>
</body>

</html>